// Sample 48000 Hz, pass 1350, stop 1750, ripple 1 dB, atten 80 dB (coef_tx).  Stop 0.036458.
double quiskMicFilt48Coefs[325] = {
 0.000070000950338734, 0.000060542525732639, 0.000084830915167248, 0.000113820318991206, 0.000147523658260692, 
 0.000185727097247136, 0.000228017694264326, 0.000273714746744222, 0.000321902242967596, 0.000371355069437399, 
 0.000420595492180569, 0.000467865412686539, 0.000511235564174107, 0.000548584697295435, 0.000577683697404093, 
 0.000596168573595124, 0.000601725499419238, 0.000592142083607333, 0.000565459097743531, 0.000519884471131262, 
 0.000454031497680723, 0.000367015380281216, 0.000258599355817496, 0.000128888056076112, -0.000021074826181109, 
-0.000189585802186493, -0.000374389987374961, -0.000572207780852182, -0.000779359325040342, -0.000991335380833019, 
-0.001203244280115714, -0.001409670281637694, -0.001605003575053789, -0.001783471817219780, -0.001939438753998784, 
-0.002067470485014850, -0.002162628068669760, -0.002220597743425130, -0.002237960051673301, -0.002212264773625852, 
-0.002142247186138010, -0.002027907322210780, -0.001870648667784210, -0.001673216059663119, -0.001439782952032160, 
-0.001175849407968695, -0.000888138367181945, -0.000584400564491252, -0.000273350274681290, 0.000035800336978808, 
 0.000333410168961052, 0.000609868204837889, 0.000855845198751289, 0.001062645743133108, 0.001222567778915907, 
 0.001329178561171123, 0.001377619146269160, 0.001364836763234778, 0.001289791422827911, 0.001153569049793089, 
 0.000959442606127223, 0.000712858984801055, 0.000421343499696318, 0.000094311703309987, -0.000257178812726900, 
-0.000620740024523200, -0.000983067401076951, -0.001330378208545664, -0.001648868642029554, -0.001925231739749957, 
-0.002147185427808426, -0.002303924955683100, -0.002386617358290471, -0.002388809260074332, -0.002306735130576522, 
-0.002139640086196955, -0.001889862283127962, -0.001562946712603551, -0.001167542853751166, -0.000715240442693352, 
-0.000220259485535331, 0.000300952307259904, 0.000830234179165372, 0.001348316435464076, 0.001835484518420602, 
 0.002272286892056382, 0.002640275270224598, 0.002922747186895021, 0.003105429025669433, 0.003177121318055631, 
 0.003130264761140124, 0.002961377569599093, 0.002671367231884301, 0.002265711108816848, 0.001754448044185524, 
 0.001152016769339380, 0.000476936676175902, -0.000248718444031171, -0.000999948124398612, -0.001749629130166096, 
-0.002469433330814752, -0.003130790556013717, -0.003705967375692800, -0.004169105103972317, -0.004497290920890501, 
-0.004671516289830527, -0.004677586380416906, -0.004506861602367489, -0.004156859083959776, -0.003631621917386205, 
-0.002941916481868308, -0.002105153002563826, -0.001145089028022731, -0.000091277027194512, 0.001021707212306502, 
 0.002155280663061357, 0.003268024493993296, 0.004317048090841251, 0.005259445594087794, 0.006053837753595639, 
 0.006661931665353417, 0.007050060676035087, 0.007190601958065676, 0.007063321534553406, 0.006656461303944376, 
 0.005967650471713226, 0.005004501271125813, 0.003784934033421286, 0.002337151835923401, 0.000699290786282728, 
-0.001081281658450751, -0.002948980083931280, -0.004841350286243770, -0.006690670765283031, -0.008425801537676034, 
-0.009974215633219711, -0.011264158097802190, -0.012226858155753686, -0.012798749185527288, -0.012923592591893964, 
-0.012554478278462186, -0.011655599268700838, -0.010203756484326235, -0.008189534541107277, -0.005618124746137401, 
-0.002509708641553183, 0.001100549166042612, 0.005162968475167027, 0.009614243563845803, 0.014378746109223314, 
 0.019370216567322070, 0.024493786616406266, 0.029648291853908371, 0.034728809072115958, 0.039629330964538544, 
 0.044245520769433347, 0.048477462256357018, 0.052232311099492307, 0.055426788736225432, 0.057989428195401226, 
 0.059862511141804443, 0.061003649799348830, 0.061386934931288717, 0.061003649799348830, 0.059862511141804443, 
 0.057989428195401226, 0.055426788736225432, 0.052232311099492307, 0.048477462256357018, 0.044245520769433347, 
 0.039629330964538544, 0.034728809072115958, 0.029648291853908371, 0.024493786616406266, 0.019370216567322070, 
 0.014378746109223314, 0.009614243563845803, 0.005162968475167027, 0.001100549166042612, -0.002509708641553183, 
-0.005618124746137401, -0.008189534541107277, -0.010203756484326235, -0.011655599268700838, -0.012554478278462186, 
-0.012923592591893964, -0.012798749185527288, -0.012226858155753686, -0.011264158097802190, -0.009974215633219711, 
-0.008425801537676034, -0.006690670765283031, -0.004841350286243770, -0.002948980083931280, -0.001081281658450751, 
 0.000699290786282728, 0.002337151835923401, 0.003784934033421286, 0.005004501271125813, 0.005967650471713226, 
 0.006656461303944376, 0.007063321534553406, 0.007190601958065676, 0.007050060676035087, 0.006661931665353417, 
 0.006053837753595639, 0.005259445594087794, 0.004317048090841251, 0.003268024493993296, 0.002155280663061357, 
 0.001021707212306502, -0.000091277027194512, -0.001145089028022731, -0.002105153002563826, -0.002941916481868308, 
-0.003631621917386205, -0.004156859083959776, -0.004506861602367489, -0.004677586380416906, -0.004671516289830527, 
-0.004497290920890501, -0.004169105103972317, -0.003705967375692800, -0.003130790556013717, -0.002469433330814752, 
-0.001749629130166096, -0.000999948124398612, -0.000248718444031171, 0.000476936676175902, 0.001152016769339380, 
 0.001754448044185524, 0.002265711108816848, 0.002671367231884301, 0.002961377569599093, 0.003130264761140124, 
 0.003177121318055631, 0.003105429025669433, 0.002922747186895021, 0.002640275270224598, 0.002272286892056382, 
 0.001835484518420602, 0.001348316435464076, 0.000830234179165372, 0.000300952307259904, -0.000220259485535331, 
-0.000715240442693352, -0.001167542853751166, -0.001562946712603551, -0.001889862283127962, -0.002139640086196955, 
-0.002306735130576522, -0.002388809260074332, -0.002386617358290471, -0.002303924955683100, -0.002147185427808426, 
-0.001925231739749957, -0.001648868642029554, -0.001330378208545664, -0.000983067401076951, -0.000620740024523200, 
-0.000257178812726900, 0.000094311703309987, 0.000421343499696318, 0.000712858984801055, 0.000959442606127223, 
 0.001153569049793089, 0.001289791422827911, 0.001364836763234778, 0.001377619146269160, 0.001329178561171123, 
 0.001222567778915907, 0.001062645743133108, 0.000855845198751289, 0.000609868204837889, 0.000333410168961052, 
 0.000035800336978808, -0.000273350274681290, -0.000584400564491252, -0.000888138367181945, -0.001175849407968695, 
-0.001439782952032160, -0.001673216059663119, -0.001870648667784210, -0.002027907322210780, -0.002142247186138010, 
-0.002212264773625852, -0.002237960051673301, -0.002220597743425130, -0.002162628068669760, -0.002067470485014850, 
-0.001939438753998784, -0.001783471817219780, -0.001605003575053789, -0.001409670281637694, -0.001203244280115714, 
-0.000991335380833019, -0.000779359325040342, -0.000572207780852182, -0.000374389987374961, -0.000189585802186493, 
-0.000021074826181109, 0.000128888056076112, 0.000258599355817496, 0.000367015380281216, 0.000454031497680723, 
 0.000519884471131262, 0.000565459097743531, 0.000592142083607333, 0.000601725499419238, 0.000596168573595124, 
 0.000577683697404093, 0.000548584697295435, 0.000511235564174107, 0.000467865412686539, 0.000420595492180569, 
 0.000371355069437399, 0.000321902242967596, 0.000273714746744222, 0.000228017694264326, 0.000185727097247136, 
 0.000147523658260692, 0.000113820318991206, 0.000084830915167248, 0.000060542525732639, 0.000070000950338734} ;

// Rate 8000, pass 1350, stop 1700, ripple 0.2 dB, Atten 100 dB, taps 93 (tune 1650). Stop 0.2125
double quiskMicFilt8Coefs[93] = { -0.000048361334397216, -0.000162172832480051, -0.000233937595698212,
-0.000006327103457766, 0.000686150429731403, 0.001555572669911020, 0.001852235322638049, 0.001010518676959113,
-0.000533703037637750, -0.001395527281294679, -0.000547805689731835, 0.001291819787342756, 0.002005877810728077,
 0.000349773034952121, -0.002188174349636707, -0.002546652809598079, 0.000326796204088075, 0.003522458156729808,
 0.002929815624806958, -0.001643263026946036, -0.005188443834846179, -0.002794087489903680, 0.003828812643532208,
 0.006979098861533383, 0.001700757602284474, -0.007013801827881641, -0.008485813922195549, 0.000867966129209818,
 0.011177153889901327, 0.009069558799223736, -0.005488279673121778, -0.016106658511052186, -0.007822070151870978,
 0.012835116756370880, 0.021388877055372072, 0.003393318192541889, -0.023987911353715568, -0.026461891098409809,
 0.006724804206592470, 0.041707244257452522, 0.030690541453250592, -0.029955120082834141, -0.077739106243522968,
-0.033499374091835024, 0.116943716609774510, 0.290907261177841880, 0.367819184749133500, 0.290907261177841880,
 0.116943716609774510, -0.033499374091835024, -0.077739106243522968, -0.029955120082834141, 0.030690541453250592,
 0.041707244257452522, 0.006724804206592470, -0.026461891098409809, -0.023987911353715568, 0.003393318192541889,
 0.021388877055372072, 0.012835116756370880, -0.007822070151870978, -0.016106658511052186, -0.005488279673121778,
 0.009069558799223736, 0.011177153889901327, 0.000867966129209818, -0.008485813922195549, -0.007013801827881641,
 0.001700757602284474, 0.006979098861533383, 0.003828812643532208, -0.002794087489903680, -0.005188443834846179,
-0.001643263026946036, 0.002929815624806958, 0.003522458156729808, 0.000326796204088075, -0.002546652809598079,
-0.002188174349636707, 0.000349773034952121, 0.002005877810728077, 0.001291819787342756, -0.000547805689731835,
-0.001395527281294679, -0.000533703037637750, 0.001010518676959113, 0.001852235322638049, 0.001555572669911020,
 0.000686150429731403, -0.000006327103457766, -0.000233937595698212, -0.000162172832480051, -0.000048361334397216} ;

// Rate 48000, pass 3000, stop 4000, ripple 0.2 dB, atten 100 dB, taps 186. Stop .083333.
double quiskLpFilt48Coefs[186] = { -0.000013634802929206, -0.000025833607451468, -0.000045098917291799,
-0.000067397454184632, -0.000087934612849518, -0.000099336288085176, -0.000092164590568194, -0.000056185338095760,
 0.000017628479128830, 0.000134695138796130, 0.000294364688920149, 0.000487930816326543, 0.000697781352809774,
 0.000898146218636447, 0.001057686434085801, 0.001143917302878051, 0.001128977827853932, 0.000995827794007123,
 0.000743730207286422, 0.000391756255003027, -0.000020838483133667, -0.000438064704829056, -0.000794512795634084,
-0.001025788840201078, -0.001080548087342285, -0.000932013104946299, -0.000586606665219995, -0.000087502631308000,
 0.000488407444073969, 0.001040518103766967, 0.001460541797297978, 0.001652270668043200, 0.001551661149061061,
 0.001143287935426198, 0.000469406269084863, -0.000371161499314815, -0.001235417370813682, -0.001958835103416428,
-0.002385048283250022, -0.002397529299276367, -0.001947179493277411, -0.001069838763968274, 0.000110976961796973,
 0.001398395929344110, 0.002552691150332272, 0.003333738458450593, 0.003548332671239537, 0.003093481207411224,
 0.001986606612550283, 0.000375208969545557, -0.001478173505667034, -0.003235390501589682, -0.004541286966345233,
-0.005091921692691575, -0.004699905483508720, -0.003343628882412480, -0.001188973425908869, 0.001423632771579898,
 0.004027852785840577, 0.006109889449352044, 0.007204411806930103, 0.006990964143613923, 0.005372067993842730,
 0.002515924626355224, -0.001148191299404085, -0.004985775758010277, -0.008258611238961837, -0.010257070307501979,
-0.010440987284724979, -0.008563091952746314, -0.004749779955204285, 0.000480411506971036, 0.006270496250094757,
 0.011548336869209398, 0.015203957673842774, 0.016294017929596276, 0.014239284159958419, 0.008979207551576943,
 0.001052260094328930, -0.008418875271295619, -0.017843305879886966, -0.025368239712008800, -0.029148572862344568,
-0.027640215600942798, -0.019871118305655480, -0.005644876301707345, 0.014359687674705773, 0.038614566536650477,
 0.064896650800270142, 0.090551963489257925, 0.112834114097579010, 0.129268306000616030, 0.137987044444314420,
 0.137987044444314420, 0.129268306000616030, 0.112834114097579010, 0.090551963489257925, 0.064896650800270142,
 0.038614566536650477, 0.014359687674705773, -0.005644876301707345, -0.019871118305655480, -0.027640215600942798,
-0.029148572862344568, -0.025368239712008800, -0.017843305879886966, -0.008418875271295619, 0.001052260094328930,
 0.008979207551576943, 0.014239284159958419, 0.016294017929596276, 0.015203957673842774, 0.011548336869209398,
 0.006270496250094757, 0.000480411506971036, -0.004749779955204285, -0.008563091952746314, -0.010440987284724979,
-0.010257070307501979, -0.008258611238961837, -0.004985775758010277, -0.001148191299404085, 0.002515924626355224,
 0.005372067993842730, 0.006990964143613923, 0.007204411806930103, 0.006109889449352044, 0.004027852785840577,
 0.001423632771579898, -0.001188973425908869, -0.003343628882412480, -0.004699905483508720, -0.005091921692691575,
-0.004541286966345233, -0.003235390501589682, -0.001478173505667034, 0.000375208969545557, 0.001986606612550283,
 0.003093481207411224, 0.003548332671239537, 0.003333738458450593, 0.002552691150332272, 0.001398395929344110,
 0.000110976961796973, -0.001069838763968274, -0.001947179493277411, -0.002397529299276367, -0.002385048283250022,
-0.001958835103416428, -0.001235417370813682, -0.000371161499314815, 0.000469406269084863, 0.001143287935426198,
 0.001551661149061061, 0.001652270668043200, 0.001460541797297978, 0.001040518103766967, 0.000488407444073969,
-0.000087502631308000, -0.000586606665219995, -0.000932013104946299, -0.001080548087342285, -0.001025788840201078,
-0.000794512795634084, -0.000438064704829056, -0.000020838483133667, 0.000391756255003027, 0.000743730207286422,
 0.000995827794007123, 0.001128977827853932, 0.001143917302878051, 0.001057686434085801, 0.000898146218636447,
 0.000697781352809774, 0.000487930816326543, 0.000294364688920149, 0.000134695138796130, 0.000017628479128830,
-0.000056185338095760, -0.000092164590568194, -0.000099336288085176, -0.000087934612849518, -0.000067397454184632,
-0.000045098917291799, -0.000025833607451468, -0.000013634802929206 } ;

// Sample 1 Hz, pass 0.125, stop 0.192, ripple 0.1 dB, atten 100 dB, taps 64.  Stop 0.192.
double quiskFilt12_19Coefs[64] = { 0.000043810351462319, 0.000138863869398690, 0.000206835545025070,
 0.000047730531591317, -0.000514727559529336, -0.001353635480056038, -0.001881242409327435, -0.001336759882352925,
 0.000480762137654505, 0.002595795305500315, 0.003157538223935716, 0.000883738175457450, -0.003304786290465149,
-0.006137600456523736, -0.004232173904239833, 0.002529546544381186, 0.009496143474996962, 0.009949625572871518,
 0.000962602913419665, -0.012260655539427043, -0.018443416827456323, -0.008986096201165510, 0.012737225552167929,
 0.030249086308101754, 0.024812387650292519, -0.007810917817793795, -0.047781081559953899, -0.059071807532626572,
-0.012800932712041477, 0.089119808681493592, 0.208124268210933110, 0.287998295491409540, 0.287998295491409540,
 0.208124268210933110, 0.089119808681493592, -0.012800932712041477, -0.059071807532626572, -0.047781081559953899,
-0.007810917817793795, 0.024812387650292519, 0.030249086308101754, 0.012737225552167929, -0.008986096201165510,
-0.018443416827456323, -0.012260655539427043, 0.000962602913419665, 0.009949625572871518, 0.009496143474996962,
 0.002529546544381186, -0.004232173904239833, -0.006137600456523736, -0.003304786290465149, 0.000883738175457450,
 0.003157538223935716, 0.002595795305500315, 0.000480762137654505, -0.001336759882352925, -0.001881242409327435,
-0.001353635480056038, -0.000514727559529336, 0.000047730531591317, 0.000206835545025070, 0.000138863869398690,
 0.000043810351462319} ;

// Sample 185185 Hz, pass 20000, stop 24000, ripple 0.1 dB, atten 100 dB.  For SDR-IQ.  Stop 0.12960.
double quiskFilt185D3Coefs[188] = { 0.000008153800001840, -0.000001771417630395, -0.000037253333929034, -0.000119009795238060,
-0.000255018503860098, -0.000431457630502916, -0.000606779374823655, -0.000718366697089728, -0.000703620301380014,
-0.000529751805487936, -0.000219462957628643, 0.000142545317473537, 0.000431747689511389, 0.000531458261578183,
 0.000388343045150861, 0.000049369127393032, -0.000342917144392365, -0.000603313895145129, -0.000587692675369399,
-0.000270442421243832, 0.000225386999468089, 0.000669074815263746, 0.000825032169620294, 0.000573830722863008,
-0.000009077307935200, -0.000664918089414559, -0.001061106586632969, -0.000955502500127749, -0.000336438190374833,
 0.000539349074607305, 0.001245645977048461, 0.001389173752996503, 0.000822043470106957, -0.000247598052622219,
-0.001319476735963911, -0.001828796700280690, -0.001437569856610004, -0.000242431773066792, 0.001222656916942065,
 0.002216144517102359, 0.002157389501918925, 0.000954312268698896, -0.000889647952809809, -0.002472890164473277,
-0.002928202444412127, -0.001887404641539060, 0.000266028947341680, 0.002515528194768854, 0.003680340277064590,
 0.003024505869869945, 0.000697099931502566, -0.002249597199494156, -0.004320335692842188, -0.004323014468691384,
-0.002034738390180464, 0.001575270318365026, 0.004732326142178709, 0.005712473175796522, 0.003763483203528208,
-0.000391719810437692, -0.004781111888508037, -0.007096880559266867, -0.005884712017661407, -0.001407862533738378,
 0.004306693842081116, 0.008352211939490001, 0.008388529075785354, 0.003946736249321500, -0.003112792599933821,
-0.009323923519118172, -0.011269282117577429, -0.007398426385575320, 0.000928531365753789, 0.009809484942446507,
 0.014553037120437585, 0.012062615692744548, 0.002683413619215453, -0.009516487432546697, -0.018375440190605826,
-0.018584023004946444, -0.008607549657362717, 0.007911844367040830, 0.023198314076417474, 0.028659214411537771,
 0.019167047651360933, -0.003633593297082508, -0.030707268487267729, -0.048352925046987114, -0.043463395046782413,
-0.009280832167164070, 0.050801866891763532, 0.123196454160356600, 0.188154012695948810, 0.226499569996940320,
 0.226499569996940320, 0.188154012695948810, 0.123196454160356600, 0.050801866891763532, -0.009280832167164070,
-0.043463395046782413, -0.048352925046987114, -0.030707268487267729, -0.003633593297082508, 0.019167047651360933,
 0.028659214411537771, 0.023198314076417474, 0.007911844367040830, -0.008607549657362717, -0.018584023004946444,
-0.018375440190605826, -0.009516487432546697, 0.002683413619215453, 0.012062615692744548, 0.014553037120437585,
 0.009809484942446507, 0.000928531365753789, -0.007398426385575320, -0.011269282117577429, -0.009323923519118172,
-0.003112792599933821, 0.003946736249321500, 0.008388529075785354, 0.008352211939490001, 0.004306693842081116,
-0.001407862533738378, -0.005884712017661407, -0.007096880559266867, -0.004781111888508037, -0.000391719810437692,
 0.003763483203528208, 0.005712473175796522, 0.004732326142178709, 0.001575270318365026, -0.002034738390180464,
-0.004323014468691384, -0.004320335692842188, -0.002249597199494156, 0.000697099931502566, 0.003024505869869945,
 0.003680340277064590, 0.002515528194768854, 0.000266028947341680, -0.001887404641539060, -0.002928202444412127,
-0.002472890164473277, -0.000889647952809809, 0.000954312268698896, 0.002157389501918925, 0.002216144517102359,
 0.001222656916942065, -0.000242431773066792, -0.001437569856610004, -0.001828796700280690, -0.001319476735963911,
-0.000247598052622219, 0.000822043470106957, 0.001389173752996503, 0.001245645977048461, 0.000539349074607305,
-0.000336438190374833, -0.000955502500127749, -0.001061106586632969, -0.000664918089414559, -0.000009077307935200,
 0.000573830722863008, 0.000825032169620294, 0.000669074815263746, 0.000225386999468089, -0.000270442421243832,
-0.000587692675369399, -0.000603313895145129, -0.000342917144392365, 0.000049369127393032, 0.000388343045150861,
 0.000531458261578183, 0.000431747689511389, 0.000142545317473537, -0.000219462957628643, -0.000529751805487936,
-0.000703620301380014, -0.000718366697089728, -0.000606779374823655, -0.000431457630502916, -0.000255018503860098,
-0.000119009795238060, -0.000037253333929034, -0.000001771417630395, 0.000008153800001840 };

// Sample 185185 Hz, pass 15000, stop 23900, ripple 0.1 dB, atten 100 dB.  For SDR-IQ.  Stop 0.129060.
double quiskFilt185D3XCoefs[88] = { -0.000026016801458962, -0.000079343977811083, -0.000167897725115826, -0.000272158478205181,
-0.000343785933253942, -0.000310796788289393, -0.000102311891399797, 0.000311300138822939, 0.000877228005105512, 0.001440583394256035,
 0.001767836749778265, 0.001621580974541500, 0.000871040137123456, -0.000402149294308734, -0.001857385353819294, -0.002952994474321905,
-0.003118971956742465, -0.002002468636632821, 0.000304795748571584, 0.003168465665729574, 0.005527734084410955, 0.006236194024480606,
 0.004538088065486723, 0.000504287301538830, -0.004776061900406583, -0.009396166048199123, -0.011236677659113514, -0.008814076686757433,
-0.002068388398230007, 0.007257051941983628, 0.015896603006282241, 0.020037182698727726, 0.016744338396284194, 0.005368795820044257,
-0.011616528320034477, -0.028774969855905743, -0.038977373476370786, -0.035506674315576942, -0.014373032297997279, 0.023936198172814224,
 0.073933459676699551, 0.126134168736811850, 0.169387884611201690, 0.193878581402395330, 0.193878581402395330, 0.169387884611201690,
 0.126134168736811850, 0.073933459676699551, 0.023936198172814224, -0.014373032297997279, -0.035506674315576942, -0.038977373476370786,
-0.028774969855905743, -0.011616528320034477, 0.005368795820044257, 0.016744338396284194, 0.020037182698727726, 0.015896603006282241,
 0.007257051941983628, -0.002068388398230007, -0.008814076686757433, -0.011236677659113514, -0.009396166048199123, -0.004776061900406583,
 0.000504287301538830, 0.004538088065486723, 0.006236194024480606, 0.005527734084410955, 0.003168465665729574, 0.000304795748571584,
-0.002002468636632821, -0.003118971956742465, -0.002952994474321905, -0.001857385353819294, -0.000402149294308734, 0.000871040137123456,
 0.001621580974541500, 0.001767836749778265, 0.001440583394256035, 0.000877228005105512, 0.000311300138822939, -0.000102311891399797,
-0.000310796788289393, -0.000343785933253942, -0.000272158478205181, -0.000167897725115826, -0.000079343977811083, -0.000026016801458962} ;

// Sample 185185 Hz, pass 10000, stop 12000, ripple 0.5 dB, atten 100 dB.  For SDR-IQ.  Stop 0.064800.
double quiskFilt185D7Coefs[325] = { 0.000011585872492535, 0.000021202775655724, 0.000038515581433427, 0.000062668164659740,
 0.000093940890103130, 0.000131718743859808, 0.000174225065604974, 0.000218342986026828, 0.000259582942086064, 0.000292202414812531,
 0.000309501208323850, 0.000304347853118504, 0.000269885084834102, 0.000200329336288352, 0.000091873319388286,
-0.000056460226867932, -0.000242180306367212, -0.000458826972767189, -0.000695972007921572, -0.000939539009494425,
-0.001172660992563646, -0.001376927020458812, -0.001534012395041686, -0.001627510712907692, -0.001644810967208332,
-0.001578811291153747, -0.001429231737210363, -0.001203341468259860, -0.000915956952592136, -0.000588604281778632,
-0.000247881153416102, 0.000076883069806609, 0.000356496498766536, 0.000564970346134735, 0.000682503931650803,
 0.000697978266499694, 0.000610677107413264, 0.000430929848100204, 0.000179551442826917, -0.000113968106450125,
-0.000414397628381283, -0.000684546545073360, -0.000889508690226669, -0.001000889233610915, -0.001000492619169160,
-0.000883003638604998, -0.000657261341613736, -0.000345878903792753, 0.000016835572177804, 0.000388523086839818,
 0.000723605124037493, 0.000978796711705906, 0.001118627280774081, 0.001120302957105695, 0.000977241071844119,
 0.000700761818102867, 0.000319615424985736, -0.000122724655145581, -0.000572787713987942, -0.000973362887973448,
-0.001270584863164685, -0.001420984914880352, -0.001397605040893653, -0.001194338356762529, -0.000827834100503333,
-0.000336591061237865, 0.000222813863757337, 0.000782022394777827, 0.001269065085645792, 0.001617440270226089,
 0.001774989493019493, 0.001711406052073067, 0.001423329284260602, 0.000936230433482062, 0.000302669877122975,
-0.000403051367712102, -0.001093347917242359, -0.001677989133371222, -0.002075657051446509, -0.002224973164684223,
-0.002093532018815395, -0.001683654864926617, -0.001033944903045330, -0.000216202715201031, 0.000672136237235640,
 0.001519308622149400, 0.002212998394841567, 0.002654922443391980, 0.002774368358702789, 0.002538866483308035,
 0.001960451088476113, 0.001096459360528461, 0.000044471086033573, -0.001068263405090781, -0.002099826730828226,
-0.002911349453455988, -0.003385273847682783, -0.003441820002543952, -0.003051407043926876, -0.002241202920048492,
-0.001094628195429446, 0.000256492779785520, 0.001646511036377237, 0.002895722994780784, 0.003833041920244146,
 0.004318777856326995, 0.004264570929820472, 0.003647733587396600, 0.002517835568167883, 0.000994251746281646,
-0.000745501220005664, -0.002485634335945939, -0.003998039828567652, -0.005071301821004867, -0.005539183731069824,
-0.005304874120435773, -0.004357624572350711, -0.002779195755674417, -0.000738704575887045, 0.001524133036686280,
 0.003725875479734138, 0.005573480900438330, 0.006801730588660005, 0.007209350069135231, 0.006689128326667765,
 0.005247829163413888, 0.003012735394874103, 0.000223174064082399, -0.002792831962376837, -0.005654763344137692,
-0.007974895792849587, -0.009407569536250765, -0.009696510630814705, -0.008714169676261001, -0.006487651574925092,
-0.003207133255888027, 0.000785450700374519, 0.005027410607157849, 0.008983570118297410, 0.012107159427564776,
 0.013906909894651421, 0.014012809617679676, 0.012232695276105182, 0.008592471450916649, 0.003354235296550607,
-0.002991194159451697, -0.009758117856276788, -0.016123999816583842, -0.021206724919405923, -0.024153695524852702,
-0.024233748891356845, -0.020922161341036132, -0.013969353698339257, -0.003445298078014795, 0.010246061695767921,
 0.026385065799221116, 0.043986586663902316, 0.061878202104145755, 0.078799201858789497, 0.093511010803744687,
 0.104908248570820360, 0.112119405527806140, 0.114587041362813750, 0.112119405527806140, 0.104908248570820360,
 0.093511010803744687, 0.078799201858789497, 0.061878202104145755, 0.043986586663902316, 0.026385065799221116,
 0.010246061695767921, -0.003445298078014795, -0.013969353698339257, -0.020922161341036132, -0.024233748891356845,
-0.024153695524852702, -0.021206724919405923, -0.016123999816583842, -0.009758117856276788, -0.002991194159451697,
 0.003354235296550607, 0.008592471450916649, 0.012232695276105182, 0.014012809617679676, 0.013906909894651421,
 0.012107159427564776, 0.008983570118297410, 0.005027410607157849, 0.000785450700374519, -0.003207133255888027,
-0.006487651574925092, -0.008714169676261001, -0.009696510630814705, -0.009407569536250765, -0.007974895792849587,
-0.005654763344137692, -0.002792831962376837, 0.000223174064082399, 0.003012735394874103, 0.005247829163413888,
 0.006689128326667765, 0.007209350069135231, 0.006801730588660005, 0.005573480900438330, 0.003725875479734138,
 0.001524133036686280, -0.000738704575887045, -0.002779195755674417, -0.004357624572350711, -0.005304874120435773,
-0.005539183731069824, -0.005071301821004867, -0.003998039828567652, -0.002485634335945939, -0.000745501220005664,
 0.000994251746281646, 0.002517835568167883, 0.003647733587396600, 0.004264570929820472, 0.004318777856326995,
 0.003833041920244146, 0.002895722994780784, 0.001646511036377237, 0.000256492779785520, -0.001094628195429446,
-0.002241202920048492, -0.003051407043926876, -0.003441820002543952, -0.003385273847682783, -0.002911349453455988,
-0.002099826730828226, -0.001068263405090781, 0.000044471086033573, 0.001096459360528461, 0.001960451088476113,
 0.002538866483308035, 0.002774368358702789, 0.002654922443391980, 0.002212998394841567, 0.001519308622149400,
 0.000672136237235640, -0.000216202715201031, -0.001033944903045330, -0.001683654864926617, -0.002093532018815395,
-0.002224973164684223, -0.002075657051446509, -0.001677989133371222, -0.001093347917242359, -0.000403051367712102,
 0.000302669877122975, 0.000936230433482062, 0.001423329284260602, 0.001711406052073067, 0.001774989493019493,
 0.001617440270226089, 0.001269065085645792, 0.000782022394777827, 0.000222813863757337, -0.000336591061237865,
-0.000827834100503333, -0.001194338356762529, -0.001397605040893653, -0.001420984914880352, -0.001270584863164685,
-0.000973362887973448, -0.000572787713987942, -0.000122724655145581, 0.000319615424985736, 0.000700761818102867,
 0.000977241071844119, 0.001120302957105695, 0.001118627280774081, 0.000978796711705906, 0.000723605124037493,
 0.000388523086839818, 0.000016835572177804, -0.000345878903792753, -0.000657261341613736, -0.000883003638604998,
-0.001000492619169160, -0.001000889233610915, -0.000889508690226669, -0.000684546545073360, -0.000414397628381283,
-0.000113968106450125, 0.000179551442826917, 0.000430929848100204, 0.000610677107413264, 0.000697978266499694,
 0.000682503931650803, 0.000564970346134735, 0.000356496498766536, 0.000076883069806609, -0.000247881153416102,
-0.000588604281778632, -0.000915956952592136, -0.001203341468259860, -0.001429231737210363, -0.001578811291153747,
-0.001644810967208332, -0.001627510712907692, -0.001534012395041686, -0.001376927020458812, -0.001172660992563646,
-0.000939539009494425, -0.000695972007921572, -0.000458826972767189, -0.000242180306367212, -0.000056460226867932,
 0.000091873319388286, 0.000200329336288352, 0.000269885084834102, 0.000304347853118504, 0.000309501208323850,
 0.000292202414812531, 0.000259582942086064, 0.000218342986026828, 0.000174225065604974, 0.000131718743859808,
 0.000093940890103130, 0.000062668164659740, 0.000038515581433427, 0.000021202775655724, 0.000011585872492535} ;

// Sample 133333 Hz, pass 20000, stop 24000, ripple 0.1 dB, atten 100 dB.  For SDR-IQ.  Stop 0.18000.
double quiskFilt133D2Coefs[136] = { 0.000017194140195307, 0.000013031580406032, -0.000070982819622986, -0.000297799318127961,
-0.000645057684247744, -0.000951723373793975, -0.000976667009837673, -0.000579840699091521, 0.000098129751533427,
 0.000644977424009104, 0.000648591932388761, 0.000063466245825653, -0.000655952785922865, -0.000858530950797784,
-0.000263313568128542, 0.000697280609267464, 0.001152025473909408, 0.000556416972642962, -0.000702600426682260,
-0.001503408593721275, -0.000962293487226091, 0.000635424413378249, 0.001893865760533597, 0.001494654948692980,
-0.000464212878209573, -0.002304129661798076, -0.002165029121341371, 0.000156986911460916, 0.002712310672598236,
 0.002984071948396753, 0.000321449210044334, -0.003091821762536665, -0.003961473137247651, -0.001010870707262950,
 0.003410242877909513, 0.005106330989341096, 0.001957278141537391, -0.003628441800145526, -0.006428886895772534,
-0.003216116999687284, 0.003699894436571663, 0.007945926308831793, 0.004862613142073883, -0.003562107867854992,
-0.009680253224586733, -0.006996529395398682, 0.003139846233471389, 0.011684868441375082, 0.009783362061267441,
-0.002313232717655680, -0.014049355073607583, -0.013495163730537300, 0.000895100102567855, 0.016959635420547809,
 0.018648538187471329, 0.001461901498462892, -0.020821848411902603, -0.026360133080398199, -0.005525410959722330,
 0.026648719554864163, 0.039549486288596822, 0.013454287175328376, -0.037723817929648518, -0.068973339495709857,
-0.034792487725714472, 0.073207163331834649, 0.211614628197181350, 0.308128392192117740, 0.308128392192117740,
 0.211614628197181350, 0.073207163331834649, -0.034792487725714472, -0.068973339495709857, -0.037723817929648518,
 0.013454287175328376, 0.039549486288596822, 0.026648719554864163, -0.005525410959722330, -0.026360133080398199,
-0.020821848411902603, 0.001461901498462892, 0.018648538187471329, 0.016959635420547809, 0.000895100102567855,
-0.013495163730537300, -0.014049355073607583, -0.002313232717655680, 0.009783362061267441, 0.011684868441375082,
 0.003139846233471389, -0.006996529395398682, -0.009680253224586733, -0.003562107867854992, 0.004862613142073883,
 0.007945926308831793, 0.003699894436571663, -0.003216116999687284, -0.006428886895772534, -0.003628441800145526,
 0.001957278141537391, 0.005106330989341096, 0.003410242877909513, -0.001010870707262950, -0.003961473137247651,
-0.003091821762536665, 0.000321449210044334, 0.002984071948396753, 0.002712310672598236, 0.000156986911460916,
-0.002165029121341371, -0.002304129661798076, -0.000464212878209573, 0.001494654948692980, 0.001893865760533597,
 0.000635424413378249, -0.000962293487226091, -0.001503408593721275, -0.000702600426682260, 0.000556416972642962,
 0.001152025473909408, 0.000697280609267464, -0.000263313568128542, -0.000858530950797784, -0.000655952785922865,
 0.000063466245825653, 0.000648591932388761, 0.000644977424009104, 0.000098129751533427, -0.000579840699091521,
-0.000976667009837673, -0.000951723373793975, -0.000645057684247744, -0.000297799318127961, -0.000070982819622986,
 0.000013031580406032, 0.000017194140195307 } ;

// Sample 133333 Hz, pass 10000, stop 12000, ripple 0.5 dB, atten 100 dB.  For SDR-IQ.  Stop 0.09000.
double quiskFilt133D5Coefs[235] = { 0.000017189993342429, 0.000044738485582654, 0.000095017992345093, 0.000171520768649681,
 0.000274754514100238, 0.000398861594001340, 0.000529984999270100, 0.000646117397525726, 0.000718766415753168,
 0.000716925008973219, 0.000612844047432097, 0.000388876459995003, 0.000043995168792169, -0.000401638582561071,
-0.000905542666180542, -0.001406385530252347, -0.001832160018119073, -0.002112253709578303, -0.002191408150519588,
-0.002042816719676478, -0.001677284024812651, -0.001145752378681760, -0.000533679761891523, 0.000052653624322135,
 0.000505907329874479, 0.000739851765907619, 0.000709229648947976, 0.000422523833395244, -0.000056020452981720,
-0.000616720304461352, -0.001125962440173316, -0.001454995787757606, -0.001509950907384681, -0.001256131267758628,
-0.000730326866325590, -0.000037158838317771, 0.000671036130692201, 0.001227356473019533, 0.001489601586267346,
 0.001376632327061763, 0.000892728515088217, 0.000132987785167989, -0.000733102122237588, -0.001497662325285410,
-0.001962695382200209, -0.001989694482613183, -0.001538410312914189, -0.000684278577781320, 0.000391518648789513,
 0.001439060262231111, 0.002196666221903917, 0.002455206790769118, 0.002114248789295101, 0.001215358226109379,
-0.000057550388771950, -0.001413462921977421, -0.002519018104662746, -0.003078793094584098, -0.002912162814601297,
-0.002007172281996295, -0.000536145063816962, 0.001173803706907478, 0.002711347438868158, 0.003677986766436793,
 0.003789135200490261, 0.002954134059121999, 0.001313489128052297, -0.000779246120784695, -0.002830527021932420,
-0.004320552674014772, -0.004832115109577898, -0.004163289510814260, -0.002394421340991988, 0.000110859904206459,
 0.002775804501582138, 0.004939612978506710, 0.006017429310863970, 0.005653427023669567, 0.003828044237650523,
 0.000888978423738288, -0.002507663812902237, -0.005538235553289072, -0.007405523728182901, -0.007541454609909858,
-0.005768568026570733, -0.002376693049722654, 0.001911054897098118, 0.006083411898142144, 0.009070202108022866,
 0.010005711453736786, 0.008463803744478828, 0.004604287191332431, -0.000813142277372015, -0.006562286180605113,
-0.011211419856533258, -0.013459517260663504, -0.012472773254562211, -0.008139991258903686, -0.001177765649827518,
 0.006953975184466299, 0.014324290436841271, 0.018945676347138025, 0.019248150626647365, 0.014509895663648657,
 0.005142708852136439, -0.007245145517153711, -0.020042796993989549, -0.030067767509750015, -0.034161762145356343,
-0.029838715290132833, -0.015854346901954634, 0.007424778279719944, 0.037939728171909451, 0.072177533053372794,
 0.105698112853527980, 0.133859311332239410, 0.152607173067114270, 0.159182344236760560, 0.152607173067114270,
 0.133859311332239410, 0.105698112853527980, 0.072177533053372794, 0.037939728171909451, 0.007424778279719944,
-0.015854346901954634, -0.029838715290132833, -0.034161762145356343, -0.030067767509750015, -0.020042796993989549,
-0.007245145517153711, 0.005142708852136439, 0.014509895663648657, 0.019248150626647365, 0.018945676347138025,
 0.014324290436841271, 0.006953975184466299, -0.001177765649827518, -0.008139991258903686, -0.012472773254562211,
-0.013459517260663504, -0.011211419856533258, -0.006562286180605113, -0.000813142277372015, 0.004604287191332431,
 0.008463803744478828, 0.010005711453736786, 0.009070202108022866, 0.006083411898142144, 0.001911054897098118,
-0.002376693049722654, -0.005768568026570733, -0.007541454609909858, -0.007405523728182901, -0.005538235553289072,
-0.002507663812902237, 0.000888978423738288, 0.003828044237650523, 0.005653427023669567, 0.006017429310863970,
 0.004939612978506710, 0.002775804501582138, 0.000110859904206459, -0.002394421340991988, -0.004163289510814260,
-0.004832115109577898, -0.004320552674014772, -0.002830527021932420, -0.000779246120784695, 0.001313489128052297,
 0.002954134059121999, 0.003789135200490261, 0.003677986766436793, 0.002711347438868158, 0.001173803706907478,
-0.000536145063816962, -0.002007172281996295, -0.002912162814601297, -0.003078793094584098, -0.002519018104662746,
-0.001413462921977421, -0.000057550388771950, 0.001215358226109379, 0.002114248789295101, 0.002455206790769118,
 0.002196666221903917, 0.001439060262231111, 0.000391518648789513, -0.000684278577781320, -0.001538410312914189,
-0.001989694482613183, -0.001962695382200209, -0.001497662325285410, -0.000733102122237588, 0.000132987785167989,
 0.000892728515088217, 0.001376632327061763, 0.001489601586267346, 0.001227356473019533, 0.000671036130692201,
-0.000037158838317771, -0.000730326866325590, -0.001256131267758628, -0.001509950907384681, -0.001454995787757606,
-0.001125962440173316, -0.000616720304461352, -0.000056020452981720, 0.000422523833395244, 0.000709229648947976,
 0.000739851765907619, 0.000505907329874479, 0.000052653624322135, -0.000533679761891523, -0.001145752378681760,
-0.001677284024812651, -0.002042816719676478, -0.002191408150519588, -0.002112253709578303, -0.001832160018119073,
-0.001406385530252347, -0.000905542666180542, -0.000401638582561071, 0.000043995168792169, 0.000388876459995003,
 0.000612844047432097, 0.000716925008973219, 0.000718766415753168, 0.000646117397525726, 0.000529984999270100,
 0.000398861594001340, 0.000274754514100238, 0.000171520768649681, 0.000095017992345093, 0.000044738485582654,
 0.000017189993342429} ;

// Sample 111111 Hz, pass 20000, stop 24000, ripple 0.1 dB, atten 100 dB.  For SDR-IQ.  Stop 0.21600.
double quiskFilt111D2Coefs[114] = { 0.000039619752517087, 0.000089439819783633, 0.000017353012666121, -0.000334808345968833,
-0.000892257134326630, -0.001221700854092078, -0.000859742027523152, 0.000086110163390211, 0.000794431841612731,
 0.000492910288706401, -0.000542730604541516, -0.001057738392194920, -0.000232619264909279, 0.001101735902638522,
 0.001208303693873524, -0.000351788978766190, -0.001781186751638964, -0.001038581835235810, 0.001330430232082531,
 0.002355496074120870, 0.000292615997120782, -0.002623102550864884, -0.002462643018753817, 0.001194053806308097,
 0.003912675164153385, 0.001670607202119238, -0.003361036335001390, -0.004638914091859385, 0.000363767953875138,
 0.005797757906125993, 0.004088942448683545, -0.003689094083671128, -0.007701448612726584, -0.001601464053307583,
 0.007864313939600763, 0.007963248868264130, -0.003156323310881499, -0.011852746523309575, -0.005390083465132761,
 0.009915212572859983, 0.014053676129843581, -0.000996935620086296, -0.017619302590712586, -0.012439281622203873,
 0.011722997082370391, 0.024364733312011930, 0.004596957308944789, -0.026911691600293927, -0.027288530345555617,
 0.013072844783675014, 0.047281998734662697, 0.021354076339639792, -0.051099079289920336, -0.080397920778604998,
 0.013794073914731197, 0.205298935938689170, 0.362799183591728360, 0.362799183591728360, 0.205298935938689170,
 0.013794073914731197, -0.080397920778604998, -0.051099079289920336, 0.021354076339639792, 0.047281998734662697,
 0.013072844783675014, -0.027288530345555617, -0.026911691600293927, 0.004596957308944789, 0.024364733312011930,
 0.011722997082370391, -0.012439281622203873, -0.017619302590712586, -0.000996935620086296, 0.014053676129843581,
 0.009915212572859983, -0.005390083465132761, -0.011852746523309575, -0.003156323310881499, 0.007963248868264130,
 0.007864313939600763, -0.001601464053307583, -0.007701448612726584, -0.003689094083671128, 0.004088942448683545,
 0.005797757906125993, 0.000363767953875138, -0.004638914091859385, -0.003361036335001390, 0.001670607202119238,
 0.003912675164153385, 0.001194053806308097, -0.002462643018753817, -0.002623102550864884, 0.000292615997120782,
 0.002355496074120870, 0.001330430232082531, -0.001038581835235810, -0.001781186751638964, -0.000351788978766190,
 0.001208303693873524, 0.001101735902638522, -0.000232619264909279, -0.001057738392194920, -0.000542730604541516,
 0.000492910288706401, 0.000794431841612731, 0.000086110163390211, -0.000859742027523152, -0.001221700854092078,
-0.000892257134326630, -0.000334808345968833, 0.000017353012666121, 0.000089439819783633, 0.000039619752517087 } ;

// Sample 111111 Hz, pass 10000, stop 12000, ripple 0.5 dB, atten 100 dB.  For SDR-IQ.  Stop 0.10800.
double quiskFilt111D4Coefs[196] = { 0.000022860383861326, 0.000070265173417164, 0.000160689233204503, 0.000301317969124407,
 0.000487289901409396, 0.000694724116305488, 0.000878636067621920, 0.000977522977076171, 0.000925771316840867,
 0.000672305339588912, 0.000201226295657756, -0.000452162019544330, -0.001196628260487459, -0.001896523042546486,
-0.002399782411882304, -0.002577406131356652, -0.002364065883391685, -0.001786962447427500, -0.000971468216463463,
-0.000117441349581108, 0.000550823899522796, 0.000848990131462632, 0.000692513431543379, 0.000131676598678132,
-0.000652871765004500, -0.001397429828707858, -0.001834711252195214, -0.001782286112376423, -0.001211048928870428,
-0.000268185005007021, 0.000757996926666718, 0.001525273309644227, 0.001751649817944780, 0.001319320688138531,
 0.000330934715806419, -0.000906405873937246, -0.001970890581915849, -0.002464861139454794, -0.002158210203051176,
-0.001085620699944977, 0.000441507737096167, 0.001920949956624443, 0.002821890381744697, 0.002772521251916338,
 0.001707992629296951, -0.000078236168178539, -0.002007203892070514, -0.003396752476301502, -0.003697747220029350,
-0.002703958879036829, -0.000657405952388967, 0.001798494644242414, 0.003814960168125246, 0.004625841420163100,
 0.003831836297877268, 0.001577797389627854, -0.001450651164746532, -0.004226329291915980, -0.005721230469088120,
-0.005278368569659456, -0.002883121089582856, 0.000773112126565357, 0.004478776308038774, 0.006893091575659842,
 0.007019574634915599, 0.004598796615908167, 0.000271268071355489, -0.004569531219948477, -0.008209861014252150,
-0.009205194241390222, -0.006929272243366950, -0.001881659896440290, 0.004379813721900100, 0.009694113972501929,
 0.012015064656800249, 0.010162418707817443, 0.004341783259066366, -0.003775178431738174, -0.011484866194632987,
-0.015901979746403339, -0.014972424881419052, -0.008312775352876528, 0.002435156726078577, 0.013913027108919607,
 0.021990371341685223, 0.023101099895195237, 0.015573244973319158, 0.000514891807100321, -0.018080409101544084,
-0.034128539734629829, -0.040997556950638683, -0.033400949657662792, -0.009105399838522790, 0.030066051833635116,
 0.078279007079479407, 0.126836610192946620, 0.166170707028785000, 0.188161385669205480, 0.188161385669205480,
 0.166170707028785000, 0.126836610192946620, 0.078279007079479407, 0.030066051833635116, -0.009105399838522790,
-0.033400949657662792, -0.040997556950638683, -0.034128539734629829, -0.018080409101544084, 0.000514891807100321,
 0.015573244973319158, 0.023101099895195237, 0.021990371341685223, 0.013913027108919607, 0.002435156726078577,
-0.008312775352876528, -0.014972424881419052, -0.015901979746403339, -0.011484866194632987, -0.003775178431738174,
 0.004341783259066366, 0.010162418707817443, 0.012015064656800249, 0.009694113972501929, 0.004379813721900100,
-0.001881659896440290, -0.006929272243366950, -0.009205194241390222, -0.008209861014252150, -0.004569531219948477,
 0.000271268071355489, 0.004598796615908167, 0.007019574634915599, 0.006893091575659842, 0.004478776308038774,
 0.000773112126565357, -0.002883121089582856, -0.005278368569659456, -0.005721230469088120, -0.004226329291915980,
-0.001450651164746532, 0.001577797389627854, 0.003831836297877268, 0.004625841420163100, 0.003814960168125246,
 0.001798494644242414, -0.000657405952388967, -0.002703958879036829, -0.003697747220029350, -0.003396752476301502,
-0.002007203892070514, -0.000078236168178539, 0.001707992629296951, 0.002772521251916338, 0.002821890381744697,
 0.001920949956624443, 0.000441507737096167, -0.001085620699944977, -0.002158210203051176, -0.002464861139454794,
-0.001970890581915849, -0.000906405873937246, 0.000330934715806419, 0.001319320688138531, 0.001751649817944780,
 0.001525273309644227, 0.000757996926666718, -0.000268185005007021, -0.001211048928870428, -0.001782286112376423,
-0.001834711252195214, -0.001397429828707858, -0.000652871765004500, 0.000131676598678132, 0.000692513431543379,
 0.000848990131462632, 0.000550823899522796, -0.000117441349581108, -0.000971468216463463, -0.001786962447427500,
-0.002364065883391685, -0.002577406131356652, -0.002399782411882304, -0.001896523042546486, -0.001196628260487459,
-0.000452162019544330, 0.000201226295657756, 0.000672305339588912, 0.000925771316840867, 0.000977522977076171,
 0.000878636067621920, 0.000694724116305488, 0.000487289901409396, 0.000301317969124407, 0.000160689233204503,
 0.000070265173417164, 0.000022860383861326} ;

// Sample 53333 Hz, pass 20000, stop 24000, ripple 0.1 dB, atten 100 dB.  For SDR-IQ.  Stop 0.45000.
double quiskFilt53D1Coefs[55] = { 0.000318858391362187, 0.001662116369387873, -0.000065237353639775, -0.000854885424783294,
 0.001693126335254083, -0.002034310867663472, 0.001354648789538254, 0.000509693525155950, -0.003079059747940221, 0.005242349925004462,
-0.005626507739484119, 0.003235398612833476, 0.001883583294529978, -0.008273775245721798, 0.013282431836060808, -0.013924391581141530,
 0.008176677795586052, 0.003763659697675038, -0.018814370186261472, 0.031357304759835808, -0.034684131608746831, 0.023184334016039702,
 0.005435239957731122, -0.048724194253317150, 0.099481724552805198, -0.147334801628740130, 0.181502639813268140, 0.806108236192275450,
 0.181502639813268140, -0.147334801628740130, 0.099481724552805198, -0.048724194253317150, 0.005435239957731122, 0.023184334016039702,
-0.034684131608746831, 0.031357304759835808, -0.018814370186261472, 0.003763659697675038, 0.008176677795586052, -0.013924391581141530,
 0.013282431836060808, -0.008273775245721798, 0.001883583294529978, 0.003235398612833476, -0.005626507739484119, 0.005242349925004462,
-0.003079059747940221, 0.000509693525155950, 0.001354648789538254, -0.002034310867663472, 0.001693126335254083, -0.000854885424783294,
-0.000065237353639775, 0.001662116369387873, 0.000318858391362187 } ;

// Sample 53333 Hz, pass 10000, stop 12000, ripple 0.5 dB, atten 100 dB.  For SDR-IQ.  Stop 0.22500.
double quiskFilt53D2Coefs[93] = { 0.000107966318729964, 0.000421475598772498, 0.000731343669484184, 0.000328611865414609,
-0.001457272471508304, -0.004143803290279123, -0.005736802939367581, -0.004303861070721504, -0.000415676176666607,
 0.002561521351129964, 0.001705074918770091, -0.001794491466202784, -0.003398011312785532, -0.000595401366072839,
 0.003389160538244070, 0.003117806598779015, -0.001738195724034938, -0.004960858372597238, -0.001539269216218705,
 0.004783351138955084, 0.005278243767957266, -0.001906381347753796, -0.007653356303201065, -0.003190874189611138,
 0.006849740993527085, 0.008664448318071482, -0.002035800124581497, -0.011780892066463697, -0.005873932705860416,
 0.009972743922291657, 0.014072286848767549, -0.002113998573380457, -0.018521807368841001, -0.010490752431554192,
 0.015285369742599874, 0.023814301314901452, -0.002148815334259815, -0.031770485009434718, -0.020238958138733353,
 0.027248391304817831, 0.048071554306549469, -0.002165663523025174, -0.075199791717139086, -0.060076551864238638,
 0.094944856808714839, 0.301769455144326630, 0.397829555404577600, 0.301769455144326630, 0.094944856808714839,
-0.060076551864238638, -0.075199791717139086, -0.002165663523025174, 0.048071554306549469, 0.027248391304817831,
-0.020238958138733353, -0.031770485009434718, -0.002148815334259815, 0.023814301314901452, 0.015285369742599874,
-0.010490752431554192, -0.018521807368841001, -0.002113998573380457, 0.014072286848767549, 0.009972743922291657,
-0.005873932705860416, -0.011780892066463697, -0.002035800124581497, 0.008664448318071482, 0.006849740993527085,
-0.003190874189611138, -0.007653356303201065, -0.001906381347753796, 0.005278243767957266, 0.004783351138955084,
-0.001539269216218705, -0.004960858372597238, -0.001738195724034938, 0.003117806598779015, 0.003389160538244070,
-0.000595401366072839, -0.003398011312785532, -0.001794491466202784, 0.001705074918770091, 0.002561521351129964,
-0.000415676176666607, -0.004303861070721504, -0.005736802939367581, -0.004143803290279123, -0.001457272471508304,
 0.000328611865414609, 0.000731343669484184, 0.000421475598772498, 0.000107966318729964} ;


// Sample 240 kHz, pass 15, stop 23.9, ripple 0. 1dB, atten 100 dB, taps 114.  For 240 to 48 decimation by 5.  Stop 0.09958.
double quiskFilt240D5Coefs[114] = { -0.000017444714121896, -0.000043389176259008, -0.000086666475464372, -0.000143622066705595,
-0.000204429258992282, -0.000250894192563019, -0.000258038648420713, -0.000198760816315186, -0.000051592624047688, 0.000190007232237523,
 0.000509003255256297, 0.000859996990289808, 0.001171187148400100, 0.001354817951508860, 0.001325999614958582, 0.001026888404781159,
 0.000450896776475450, -0.000340058091672613, -0.001212260716607277, -0.001975712012888962, -0.002419081295027340, -0.002359587962889753,
-0.001697757353388466, -0.000463309281242825, 0.001162369385377015, 0.002858574184542211, 0.004216991598475732, 0.004827550436585937,
 0.004383011824547803, 0.002778680650352727, 0.000180287057286554, -0.002963889630832239, -0.005980581348043338, -0.008097241865875090,
-0.008616599305826346, -0.007104942880323794, -0.003549433861261754, 0.001560075425221182, 0.007257901257043677, 0.012249987278338943,
 0.015166545447995922, 0.014877026236042860, 0.010803636353332058, 0.003161070172512297, -0.006942541244647841, -0.017585167076596235,
-0.026297182632904086, -0.030480128886681127, -0.027906762548949221, -0.017206725660431417, 0.001763368880847165, 0.027750612266565198,
 0.058186952307218993, 0.089522326728125629, 0.117760091355900630, 0.139101943345962650, 0.150584021572851110, 0.150584021572851110,
 0.139101943345962650, 0.117760091355900630, 0.089522326728125629, 0.058186952307218993, 0.027750612266565198, 0.001763368880847165,
-0.017206725660431417, -0.027906762548949221, -0.030480128886681127, -0.026297182632904086, -0.017585167076596235, -0.006942541244647841,
 0.003161070172512297, 0.010803636353332058, 0.014877026236042860, 0.015166545447995922, 0.012249987278338943, 0.007257901257043677,
 0.001560075425221182, -0.003549433861261754, -0.007104942880323794, -0.008616599305826346, -0.008097241865875090, -0.005980581348043338,
-0.002963889630832239, 0.000180287057286554, 0.002778680650352727, 0.004383011824547803, 0.004827550436585937, 0.004216991598475732,
 0.002858574184542211, 0.001162369385377015, -0.000463309281242825, -0.001697757353388466, -0.002359587962889753, -0.002419081295027340,
-0.001975712012888962, -0.001212260716607277, -0.000340058091672613, 0.000450896776475450, 0.001026888404781159, 0.001325999614958582,
 0.001354817951508860, 0.001171187148400100, 0.000859996990289808, 0.000509003255256297, 0.000190007232237523, -0.000051592624047688,
-0.000198760816315186, -0.000258038648420713, -0.000250894192563019, -0.000204429258992282, -0.000143622066705595, -0.000086666475464372,
-0.000043389176259008, -0.000017444714121896} ;

// Sample 240 kHz, pass 20, stop 24, ripple 0. 1dB, atten 100 dB, taps 114.  For 240 to 48 decimation by 5.  Stop 0.1000.
double quiskFilt240D5CoefsSharp[246] = { 0.000011951828200011, 0.000019798433756403, 0.000028547330106604, 0.000030165284908057,
 0.000016460532579755, -0.000020835366942643, -0.000087256395370183, -0.000182447830402188, -0.000297836387286273,
-0.000416082361724969, -0.000513090543707066, -0.000562800094080439, -0.000543922161049598, -0.000447038893351438,
-0.000279964105369211, -0.000069269573936326, 0.000143339868281261, 0.000309776397278667, 0.000387771231401110,
 0.000353469185042608, 0.000210686954436390, -0.000006554284588476, -0.000240063519947365, -0.000421527417296624,
-0.000491443283168306, -0.000417820101680067, -0.000208868052760534, 0.000085048027839757, 0.000382180878613336,
 0.000591123735768924, 0.000638042870263572, 0.000491558598565883, 0.000177179393286866, -0.000224481053594759,
-0.000597014064504330, -0.000820930704466417, -0.000810918218693337, -0.000546326732285124, -0.000084459306793206,
 0.000449422013818846, 0.000894687281371102, 0.001102541594699144, 0.000984325470442889, 0.000545624937191001,
-0.000106146183328305, -0.000785797405770491, -0.001281535037100789, -0.001419612701203994, -0.001123137180667268,
-0.000445673862380164, 0.000433514280597531, 0.001254730807221768, 0.001752968220115270, 0.001741675133186359,
 0.001179202567033726, 0.000195102369455356, -0.000935783344044036, -0.001867876483977602, -0.002288593398642863,
-0.002020698232986274, -0.001090456401574151, 0.000263178814654847, 0.001646402890369986, 0.002622726888175473,
 0.002848310252497599, 0.002189220340667481, 0.000781654013623377, -0.000988901141783250, -0.002589700588821625,
-0.003498176390167329, -0.003369141152473258, -0.002159241772770695, -0.000165464996932323, 0.002041618007644499,
 0.003777187265991297, 0.004450866229775656, 0.003762315917274342, 0.001820394865830094, -0.000858234059046015,
-0.003480363951041699, -0.005206132491721142, -0.005412440056656052, -0.003908911556192801, -0.001033963211572532,
 0.002409267811432101, 0.005369858454077349, 0.006862619655562839, 0.006286791984567192, 0.003649433286047820,
-0.000385090824056697, -0.004649684536230074, -0.007801516508809942, -0.008732884415488085, -0.006943637236744675,
-0.002754601930921507, 0.002718968772510816, 0.007846810206617289, 0.010951016745475875, 0.010832279872067337,
 0.007196213900006544, 0.000837720738654166, -0.006496855603590420, -0.012558347528192997, -0.015246550948573622,
-0.013285617706403107, -0.006719315573973105, 0.002942907242266441, 0.013010190699738699, 0.020286552390091313,
 0.021982424443790855, 0.016621666248368951, 0.004683273039499340, -0.011231582005110220, -0.026802267461528154,
-0.036907110368292514, -0.036858745295310878, -0.023657596515413496, 0.003060851507965577, 0.040649713296411087,
 0.083777373113400611, 0.125416065458074430, 0.158282028171104980, 0.176396323031566690, 0.176396323031566690,
 0.158282028171104980, 0.125416065458074430, 0.083777373113400611, 0.040649713296411087, 0.003060851507965577,
-0.023657596515413496, -0.036858745295310878, -0.036907110368292514, -0.026802267461528154, -0.011231582005110220,
 0.004683273039499340, 0.016621666248368951, 0.021982424443790855, 0.020286552390091313, 0.013010190699738699,
 0.002942907242266441, -0.006719315573973105, -0.013285617706403107, -0.015246550948573622, -0.012558347528192997,
-0.006496855603590420, 0.000837720738654166, 0.007196213900006544, 0.010832279872067337, 0.010951016745475875,
 0.007846810206617289, 0.002718968772510816, -0.002754601930921507, -0.006943637236744675, -0.008732884415488085,
-0.007801516508809942, -0.004649684536230074, -0.000385090824056697, 0.003649433286047820, 0.006286791984567192,
 0.006862619655562839, 0.005369858454077349, 0.002409267811432101, -0.001033963211572532, -0.003908911556192801,
-0.005412440056656052, -0.005206132491721142, -0.003480363951041699, -0.000858234059046015, 0.001820394865830094,
 0.003762315917274342, 0.004450866229775656, 0.003777187265991297, 0.002041618007644499, -0.000165464996932323,
-0.002159241772770695, -0.003369141152473258, -0.003498176390167329, -0.002589700588821625, -0.000988901141783250,
 0.000781654013623377, 0.002189220340667481, 0.002848310252497599, 0.002622726888175473, 0.001646402890369986,
 0.000263178814654847, -0.001090456401574151, -0.002020698232986274, -0.002288593398642863, -0.001867876483977602,
-0.000935783344044036, 0.000195102369455356, 0.001179202567033726, 0.001741675133186359, 0.001752968220115270,
 0.001254730807221768, 0.000433514280597531, -0.000445673862380164, -0.001123137180667268, -0.001419612701203994,
-0.001281535037100789, -0.000785797405770491, -0.000106146183328305, 0.000545624937191001, 0.000984325470442889,
 0.001102541594699144, 0.000894687281371102, 0.000449422013818846, -0.000084459306793206, -0.000546326732285124,
-0.000810918218693337, -0.000820930704466417, -0.000597014064504330, -0.000224481053594759, 0.000177179393286866,
 0.000491558598565883, 0.000638042870263572, 0.000591123735768924, 0.000382180878613336, 0.000085048027839757,
-0.000208868052760534, -0.000417820101680067, -0.000491443283168306, -0.000421527417296624, -0.000240063519947365,
-0.000006554284588476, 0.000210686954436390, 0.000353469185042608, 0.000387771231401110, 0.000309776397278667,
 0.000143339868281261, -0.000069269573936326, -0.000279964105369211, -0.000447038893351438, -0.000543922161049598,
-0.000562800094080439, -0.000513090543707066, -0.000416082361724969, -0.000297836387286273, -0.000182447830402188,
-0.000087256395370183, -0.000020835366942643, 0.000016460532579755, 0.000030165284908057, 0.000028547330106604,
 0.000019798433756403, 0.000011951828200011 };

// Sample 48 kHz, pass 10, stop 12, ripple 0.1 dB, atten 100 dB.  Stop 0.25000.
double quiskFilt48dec24Coefs[98] = { 0.000036864882767612, 0.000009858596392836, -0.000330770380800406, -0.001009174072411182,
-0.001404963853116591, -0.000770236458542885, 0.000523955998497470, 0.000947009978368078, -0.000170647420729277, -0.001215337186275615,
-0.000339882761263432, 0.001380697691347411, 0.001052816245779061, -0.001289457483737270, -0.001905995022750999,
 0.000806360758757266, 0.002752294066736399, 0.000151371304906695, -0.003382080182092562, -0.001586160863198252,
 0.003550356871637037, 0.003397108074666923, -0.003014198882506884, -0.005368247151920206, 0.001578030229641401,
 0.007172700113962798, 0.000859017219495951, -0.008394441438252027, -0.004260927420042382, 0.008565389049746911,
 0.008423570232799422, -0.007213182430375741, -0.012960608818773384, 0.003906137602881253, 0.017299646590834120,
 0.001710647317106962, -0.020687435471124054, -0.009911496013769150, 0.022192116474879110, 0.020997544995749250,
-0.020577450597980520, -0.035567363858049900, 0.013892294138831605, 0.055472458661532512, 0.002296277239682308,
-0.087929779622300100, -0.045452533452794319, 0.182125569604839360, 0.410917417297433360, 0.410917417297433360,
 0.182125569604839360, -0.045452533452794319, -0.087929779622300100, 0.002296277239682308, 0.055472458661532512,
 0.013892294138831605, -0.035567363858049900, -0.020577450597980520, 0.020997544995749250, 0.022192116474879110,
-0.009911496013769150, -0.020687435471124054, 0.001710647317106962, 0.017299646590834120, 0.003906137602881253,
-0.012960608818773384, -0.007213182430375741, 0.008423570232799422, 0.008565389049746911, -0.004260927420042382,
-0.008394441438252027, 0.000859017219495951, 0.007172700113962798, 0.001578030229641401, -0.005368247151920206,
-0.003014198882506884, 0.003397108074666923, 0.003550356871637037, -0.001586160863198252, -0.003382080182092562,
 0.000151371304906695, 0.002752294066736399, 0.000806360758757266, -0.001905995022750999, -0.001289457483737270,
 0.001052816245779061, 0.001380697691347411, -0.000339882761263432, -0.001215337186275615, -0.000170647420729277,
 0.000947009978368078, 0.000523955998497470, -0.000770236458542885, -0.001404963853116591, -0.001009174072411182,
-0.000330770380800406, 0.000009858596392836, 0.000036864882767612} ;

// Sample 24 kHz, pass 4, stop 6, ripple 0.2 dB, atten 100 dB.  Stop 0.25000.
double quiskAudio24p4Coefs[47] = { -0.000088032928341076, -0.000644655891856698, -0.001950684938386873, -0.003218845681314026,
-0.002450782287864210, 0.001217506567762789, 0.004686926326285676, 0.002765800843238593, -0.004566450766965229, -0.008584510412060854,
-0.000971556018221359, 0.012083832500170146, 0.012188815169382777, -0.007290936633701373, -0.024348624812992169, -0.010068583077594291,
 0.027777796699414107, 0.039152990662982279, -0.009401736137370085, -0.072784723467554810, -0.051588082257896843, 0.099826186027899166,
 0.298074745160505860, 0.389807370973666690, 0.298074745160505860, 0.099826186027899166, -0.051588082257896843, -0.072784723467554810,
-0.009401736137370085, 0.039152990662982279, 0.027777796699414107, -0.010068583077594291, -0.024348624812992169, -0.007290936633701373,
 0.012188815169382777, 0.012083832500170146, -0.000971556018221359, -0.008584510412060854, -0.004566450766965229, 0.002765800843238593,
 0.004686926326285676, 0.001217506567762789, -0.002450782287864210, -0.003218845681314026, -0.001950684938386873, -0.000644655891856698,
-0.000088032928341076} ;

// Sample 24 kHz, pass 6, stop 8, ripple 0.5 dB, atten 80 dB.  Stop 0.33333.
double quiskAudio24p6Coefs[36] = { 0.001199140008010727, 0.005953815908571521, 0.008621055763448699, -0.000319602525571569,
-0.008665733839154772, 0.003122601697996235, 0.011839435384729619, -0.008973143363910490, -0.014884256392667099, 0.019451226278492342,
 0.015232717446420085, -0.036364345084318225, -0.008723687718470995, 0.063232433222709966, -0.014104739941611717, -0.115885442639735490,
 0.103975832351096060, 0.487646324142562260, 0.487646324142562260, 0.103975832351096060, -0.115885442639735490, -0.014104739941611717,
 0.063232433222709966, -0.008723687718470995, -0.036364345084318225, 0.015232717446420085, 0.019451226278492342, -0.014884256392667099,
-0.008973143363910490, 0.011839435384729619, 0.003122601697996235, -0.008665733839154772, -0.000319602525571569, 0.008621055763448699,
 0.005953815908571521, 0.001199140008010727} ;

// Sample 48 kHz, pass 6, stop 8, ripple 0.5 dB, atten 80 dB.  Stop 0.16667.
double quiskAudio48p6Coefs[71] = { 0.000324677779792651, 0.001038192405843851, 0.002082337464742640, 0.002938055116822665,
 0.002811674671240099, 0.001132278163758895, -0.001835394694865431, -0.004766409947196539, -0.005833007003128954, -0.003914015660218843,
 0.000296099005521212, 0.004239593489554206, 0.004918390640978499, 0.001100872619673516, -0.005241634309386784,
-0.009658192522859132, -0.008117324326241930, -0.000324815284776402, 0.009102631659469559, 0.013098226740520415,
 0.007176675441219364, -0.006349840429806648, -0.018522542400385748, -0.019189364957006558, -0.004749023128788906,
 0.017303403623348305, 0.031306220127229140, 0.023400239035184393, -0.007229519056042042, -0.043717246110810550,
-0.058176618846235130, -0.027325746983863020, 0.051711450483087174, 0.155566868220561340, 0.243667260926508620,
 0.278152523812557280, 0.243667260926508620, 0.155566868220561340, 0.051711450483087174, -0.027325746983863020,
-0.058176618846235130, -0.043717246110810550, -0.007229519056042042, 0.023400239035184393, 0.031306220127229140,
 0.017303403623348305, -0.004749023128788906, -0.019189364957006558, -0.018522542400385748, -0.006349840429806648,
 0.007176675441219364, 0.013098226740520415, 0.009102631659469559, -0.000324815284776402, -0.008117324326241930,
-0.009658192522859132, -0.005241634309386784, 0.001100872619673516, 0.004918390640978499, 0.004239593489554206,
 0.000296099005521212, -0.003914015660218843, -0.005833007003128954, -0.004766409947196539, -0.001835394694865431,
 0.001132278163758895, 0.002811674671240099, 0.002938055116822665, 0.002082337464742640, 0.001038192405843851,
 0.000324677779792651} ;

// Sample 96 kHz, pass 6, stop 40, ripple 0.1 dB, atten 100 dB.  Stop 0.41667.
double quiskAudio96Coefs[11] = { -0.004756607210954994, -0.022893760473075838, -0.023609616122334920,
 0.078161168368381481, 0.277880235815005590, 0.388489826271597950, 0.277880235815005590,
 0.078161168368381481, -0.023609616122334920, -0.022893760473075838, -0.004756607210954994} ;


// Sample 12000 kHz, high pass, stop 180, pass 300, ripple 0.2 dB, atten 80 dB.
double quiskAudioFmHpCoefs[309] = { 0.004847574947800705, -0.001211970386842814, -0.001072277374239886, -0.000949749961336003,
-0.000841696354699768, -0.000745515693376396, -0.000658731927598885, -0.000579117971409598, -0.000504808183463150, -0.000434052387522716,
-0.000365311474947399, -0.000297420057921267, -0.000229505695217796, -0.000160920338573639, -0.000091306103977099, -0.000020600671979957,
 0.000051022545303487, 0.000123144667419350, 0.000195091536211946, 0.000265999359621072, 0.000334844261309097, 0.000400429077199748,
 0.000461460673600523, 0.000516639603401830, 0.000564613893906762, 0.000603966827912324, 0.000633383885155741, 0.000651723486505544,
 0.000657887414710607, 0.000650908078289207, 0.000630221666830102, 0.000595435888069700, 0.000546108904674455, 0.000484276489349049,
 0.000401543327440382, 0.000321419603506285, 0.000213106256109367, 0.000098353002391692, -0.000019740287652141, -0.000144911454925575,
-0.000277381849908065, -0.000413476038173425, -0.000548427361576298, -0.000678490099554352, -0.000801069365710719, -0.000914049078670187,
-0.001015286248346293, -0.001102331400542105, -0.001172396297916355, -0.001222632870457348, -0.001250498303855702, -0.001253983783014675,
-0.001231724573461644, -0.001182999511712966, -0.001107609474592948, -0.001005802502109255, -0.000878333102915519, -0.000726459269042778,
-0.000551839538058223, -0.000356598632546370, -0.000143511677076383, 0.000084082690787220, 0.000322510489680255, 0.000567640643123008,
 0.000814725473802231, 0.001058851063175263, 0.001295215851931261, 0.001517809497406495, 0.001723717744529424, 0.001902986849115314,
 0.002058196188280081, 0.002178885915107971, 0.002262004073121292, 0.002306568447922007, 0.002308817130050681, 0.002265197627398382,
 0.002174415827424258, 0.002036784086082496, 0.001852852576328433, 0.001623326794876901, 0.001349852467618926, 0.001035442578833791,
 0.000684336173595900, 0.000301699601011732, -0.000106613479977550, -0.000534173868829619, -0.000973944167066713, -0.001418238552947833,
-0.001858773604862586, -0.002286765126902860, -0.002693131197271969, -0.003068872591348129, -0.003405360512862820, -0.003694294048148267,
-0.003927679645897309, -0.004098170195163846, -0.004199334823619039, -0.004225516845056660, -0.004171926884864147, -0.004035318109791245,
-0.003814086552001789, -0.003507185822613928, -0.003116677958603595, -0.002643536244472083, -0.002094553515010935, -0.001473198308268938,
-0.000787663079055384, -0.000048057914319065, 0.000736224014748010, 0.001553680380245313, 0.002390615203692300, 0.003232587312827377,
 0.004064917562862491, 0.004872099692091644, 0.005637649839955575, 0.006344792681250736, 0.006977074214765010, 0.007518456060848391,
 0.007953298539805269, 0.008266566568951741, 0.008444193362869966, 0.008473441636160825, 0.008343141792745356, 0.008043815615010122,
 0.007567858472781280, 0.006909789777373219, 0.006066331643824790, 0.005036377728498742, 0.003821244456796700, 0.002425048400384444,
 0.000854549919626146, -0.000881361873217043, -0.002771584559469569, -0.004802304296173217, -0.006957451254254373, -0.009219821548686471,
-0.011569065498728633, -0.013984260863667768, -0.016442032516463558, -0.018919305853375375, -0.021391356610149178, -0.023832595189340611,
-0.026218718241990988, -0.028524575634244292, -0.030725193547532524, -0.032797022202043544, -0.034717887030001365, -0.036466683292335302,
-0.038023870249327039, -0.039372161079335152, -0.040496648982101487, -0.041384719119703033, -0.042026270620733261, -0.042414057053836371,
 0.957456210208300410, -0.042414057053836371, -0.042026270620733261, -0.041384719119703033, -0.040496648982101487, -0.039372161079335152,
-0.038023870249327039, -0.036466683292335302, -0.034717887030001365, -0.032797022202043544, -0.030725193547532524, -0.028524575634244292,
-0.026218718241990988, -0.023832595189340611, -0.021391356610149178, -0.018919305853375375, -0.016442032516463558, -0.013984260863667768,
-0.011569065498728633, -0.009219821548686471, -0.006957451254254373, -0.004802304296173217, -0.002771584559469569, -0.000881361873217043,
 0.000854549919626146, 0.002425048400384444, 0.003821244456796700, 0.005036377728498742, 0.006066331643824790, 0.006909789777373219,
 0.007567858472781280, 0.008043815615010122, 0.008343141792745356, 0.008473441636160825, 0.008444193362869966, 0.008266566568951741,
 0.007953298539805269, 0.007518456060848391, 0.006977074214765010, 0.006344792681250736, 0.005637649839955575, 0.004872099692091644,
 0.004064917562862491, 0.003232587312827377, 0.002390615203692300, 0.001553680380245313, 0.000736224014748010, -0.000048057914319065,
-0.000787663079055384, -0.001473198308268938, -0.002094553515010935, -0.002643536244472083, -0.003116677958603595, -0.003507185822613928,
-0.003814086552001789, -0.004035318109791245, -0.004171926884864147, -0.004225516845056660, -0.004199334823619039, -0.004098170195163846,
-0.003927679645897309, -0.003694294048148267, -0.003405360512862820, -0.003068872591348129, -0.002693131197271969, -0.002286765126902860,
-0.001858773604862586, -0.001418238552947833, -0.000973944167066713, -0.000534173868829619, -0.000106613479977550, 0.000301699601011732,
 0.000684336173595900, 0.001035442578833791, 0.001349852467618926, 0.001623326794876901, 0.001852852576328433, 0.002036784086082496,
 0.002174415827424258, 0.002265197627398382, 0.002308817130050681, 0.002306568447922007, 0.002262004073121292, 0.002178885915107971,
 0.002058196188280081, 0.001902986849115314, 0.001723717744529424, 0.001517809497406495, 0.001295215851931261, 0.001058851063175263,
 0.000814725473802231, 0.000567640643123008, 0.000322510489680255, 0.000084082690787220, -0.000143511677076383, -0.000356598632546370,
-0.000551839538058223, -0.000726459269042778, -0.000878333102915519, -0.001005802502109255, -0.001107609474592948, -0.001182999511712966,
-0.001231724573461644, -0.001253983783014675, -0.001250498303855702, -0.001222632870457348, -0.001172396297916355, -0.001102331400542105,
-0.001015286248346293, -0.000914049078670187, -0.000801069365710719, -0.000678490099554352, -0.000548427361576298, -0.000413476038173425,
-0.000277381849908065, -0.000144911454925575, -0.000019740287652141, 0.000098353002391692, 0.000213106256109367, 0.000321419603506285,
 0.000401543327440382, 0.000484276489349049, 0.000546108904674455, 0.000595435888069700, 0.000630221666830102, 0.000650908078289207,
 0.000657887414710607, 0.000651723486505544, 0.000633383885155741, 0.000603966827912324, 0.000564613893906762, 0.000516639603401830,
 0.000461460673600523, 0.000400429077199748, 0.000334844261309097, 0.000265999359621072, 0.000195091536211946, 0.000123144667419350,
 0.000051022545303487, -0.000020600671979957, -0.000091306103977099, -0.000160920338573639, -0.000229505695217796, -0.000297420057921267,
-0.000365311474947399, -0.000434052387522716, -0.000504808183463150, -0.000579117971409598, -0.000658731927598885, -0.000745515693376396,
-0.000841696354699768, -0.000949749961336003, -0.001072277374239886, -0.001211970386842814, 0.004847574947800705} ;

// Sample 24 kHz, pass 3, stop 4, ripple 0.2 dB, atten 100 dB.  Stop 0.166667.
double quiskAudio24p3Coefs[93] = { -0.000037783993624828, -0.000115216534351507, -0.000197004848051633, -0.000166882497461099,
 0.000128538373562514, 0.000763065896965353, 0.001593251408880778, 0.002221476977470587, 0.002159957821475971, 0.001165685783386774,
-0.000455884791825150, -0.001852148041710624, -0.002061857791611326, -0.000704774303788570, 0.001548186623458437, 0.003181880133780748,
 0.002773578777222453, 0.000127448157901667, -0.003249774740083473, -0.004900026839230316, -0.003119142778828723, 0.001505846985194979,
 0.006005835857891277, 0.006816532154902235, 0.002465206003840461, -0.004779621260530268, -0.009853981311881564, -0.008278389476095381,
 0.000168292207858724, 0.010329120063920900, 0.014549834598444522, 0.008161510823584768, -0.006176039595703008, -0.018913340959814302,
-0.019528202468339487, -0.004537713172735999, 0.018084136858548469, 0.032234903031086101, 0.023988321525860046, -0.007153715631741163,
-0.043920635751648937, -0.058267538333419230, -0.027093916052665576, 0.052156072898706766, 0.155951479742186460, 0.243837576013442580,
 0.278208881979582880, 0.243837576013442580, 0.155951479742186460, 0.052156072898706766, -0.027093916052665576, -0.058267538333419230,
-0.043920635751648937, -0.007153715631741163, 0.023988321525860046, 0.032234903031086101, 0.018084136858548469, -0.004537713172735999,
-0.019528202468339487, -0.018913340959814302, -0.006176039595703008, 0.008161510823584768, 0.014549834598444522, 0.010329120063920900,
 0.000168292207858724, -0.008278389476095381, -0.009853981311881564, -0.004779621260530268, 0.002465206003840461, 0.006816532154902235,
 0.006005835857891277, 0.001505846985194979, -0.003119142778828723, -0.004900026839230316, -0.003249774740083473, 0.000127448157901667,
 0.002773578777222453, 0.003181880133780748, 0.001548186623458437, -0.000704774303788570, -0.002061857791611326, -0.001852148041710624,
-0.000455884791825150, 0.001165685783386774, 0.002159957821475971, 0.002221476977470587, 0.001593251408880778, 0.000763065896965353,
 0.000128538373562514, -0.000166882497461099, -0.000197004848051633, -0.000115216534351507, -0.000037783993624828} ;

// Sample 166.667 kHz, pass 20.000, stop 23.900, ripple 0.1dB, atten 100 dB.  Stop 0.143400.
double quiskFilt167D3Coefs[173] = { 0.000027361057967466, 0.000079022927580003, 0.000153315280214681, 0.000217036303406228,
 0.000216051711988195, 0.000097396424148557, -0.000154926195574306, -0.000490420382204739, -0.000792207008833313,
-0.000919092591781850, -0.000778111000786101, -0.000391274475742801, 0.000087636155699997, 0.000431036292372644,
 0.000453513042034128, 0.000127278368774421, -0.000375305195602114, -0.000754032727213185, -0.000745162366934028,
-0.000291077295308464, 0.000391691804410550, 0.000907469994025008, 0.000906322210882447, 0.000315586781248832,
-0.000570606431536495, -0.001224850102488048, -0.001191706572954991, -0.000392843729362266, 0.000766771909476392,
 0.001591024783572854, 0.001502286627641521, 0.000433072083786191, -0.001058714434132909, -0.002065657351825392,
-0.001872596976495124, -0.000447193062325162, 0.001448204360826397, 0.002647575301181126, 0.002286703308575930,
 0.000403725700513730, -0.001971005587443560, -0.003359964169317242, -0.002743264224337261, -0.000278054902152837,
 0.002659789549535132, 0.004222291522979791, 0.003233725726619094, 0.000035039391335235, -0.003557779274022707,
-0.005259805099663439, -0.003746914316541065, 0.000371441180756436, 0.004722776316977453, 0.006507912944025527,
 0.004270009795668968, -0.001002952818151785, -0.006235533234742016, -0.008019243636496016, -0.004787772358159753,
 0.001948724018108411, 0.008220101302576532, 0.009881282059334088, 0.005283717292111678, -0.003348783872543343,
-0.010884795691042899, -0.012252153446073137, -0.005739902334679721, 0.005449960457274001, 0.014621846680862713,
 0.015450997622704835, 0.006140561144775123, -0.008746269854437872, -0.020270474363958398, -0.020205028153266937,
-0.006470785151112811, 0.014438262597161191, 0.030022509645911820, 0.028563858550479816, 0.006716896161104373,
-0.026463233531944890, -0.051946702805221123, -0.049198922096865508, -0.006868026781416496, 0.069760519092899292,
 0.158783283295639180, 0.229837831554147300, 0.256919080611963280, 0.229837831554147300, 0.158783283295639180,
 0.069760519092899292, -0.006868026781416496, -0.049198922096865508, -0.051946702805221123, -0.026463233531944890,
 0.006716896161104373, 0.028563858550479816, 0.030022509645911820, 0.014438262597161191, -0.006470785151112811,
-0.020205028153266937, -0.020270474363958398, -0.008746269854437872, 0.006140561144775123, 0.015450997622704835,
 0.014621846680862713, 0.005449960457274001, -0.005739902334679721, -0.012252153446073137, -0.010884795691042899,
-0.003348783872543343, 0.005283717292111678, 0.009881282059334088, 0.008220101302576532, 0.001948724018108411,
-0.004787772358159753, -0.008019243636496016, -0.006235533234742016, -0.001002952818151785, 0.004270009795668968,
 0.006507912944025527, 0.004722776316977453, 0.000371441180756436, -0.003746914316541065, -0.005259805099663439,
-0.003557779274022707, 0.000035039391335235, 0.003233725726619094, 0.004222291522979791, 0.002659789549535132,
-0.000278054902152837, -0.002743264224337261, -0.003359964169317242, -0.001971005587443560, 0.000403725700513730,
 0.002286703308575930, 0.002647575301181126, 0.001448204360826397, -0.000447193062325162, -0.001872596976495124,
-0.002065657351825392, -0.001058714434132909, 0.000433072083786191, 0.001502286627641521, 0.001591024783572854,
 0.000766771909476392, -0.000392843729362266, -0.001191706572954991, -0.001224850102488048, -0.000570606431536495,
 0.000315586781248832, 0.000906322210882447, 0.000907469994025008, 0.000391691804410550, -0.000291077295308464,
-0.000745162366934028, -0.000754032727213185, -0.000375305195602114, 0.000127278368774421, 0.000453513042034128,
 0.000431036292372644, 0.000087636155699997, -0.000391274475742801, -0.000778111000786101, -0.000919092591781850,
-0.000792207008833313, -0.000490420382204739, -0.000154926195574306, 0.000097396424148557, 0.000216051711988195,
 0.000217036303406228, 0.000153315280214681, 0.000079022927580003, 0.000027361057967466 } ;

// Sample 8000 Hz, stop 0 to 120, pass 300 to 2700, stop 2900 to 4000, ripple 0.1dB, atten 100 dB.
double quiskFiltTx8kAudioB[168] = { 0.000382863369135811, 0.001125903700328483, 0.000925837447276999, -0.000374734941094989,
-0.000888985517068820, -0.000361216817648551, -0.000190964056763804, -0.000521640215250387, -0.000810984560171181,
-0.000586556150016652, -0.000283591051604510, -0.000870238259790123, -0.000852903625374087, 0.000024159967210229,
-0.000630232168612451, -0.000785665131620066, 0.000569610938158391, -0.000138017351197930, -0.000362220277410620,
 0.001366339327936554, 0.000470327395373754, 0.000284347316273074, 0.002255344271539108, 0.000942593074105167,
 0.000895615209137272, 0.002941734992852122, 0.000961093640197151, 0.001177319952191160, 0.003099108113624071,
 0.000249508373597955, 0.000915783375976514, 0.002501346935887695, -0.001290867165414506, 0.000106788350951055,
 0.001148919726851922, -0.003476112709865105, -0.000973631179709113, -0.000674076242033701, -0.005811280332409654,
-0.001784274911171613, -0.002440004582391299, -0.007574097052077259, -0.001651967564004321, -0.003534348839131837,
-0.008009304387660080, 0.000005086297602882, -0.003482125314769407, -0.006580016297377269, 0.003414827979152467,
-0.002192304121179012, -0.003207666910599826, 0.008239448308648542, -0.000120276288831242, 0.001601392930489681,
 0.013506207426436229, 0.001723883024608883, 0.006793369654665180, 0.017715945730523756, 0.001956966866997749,
 0.011004187010827985, 0.019134477971688185, -0.000836412988146811, 0.012945050783659821, 0.016195220864669575,
-0.007677125676925340, 0.011863897915831447, 0.007909156115753185, -0.018792331215007903, 0.007957114843116177,
-0.005919014059116164, -0.033405211299572850, 0.002675271476407882, -0.024817610540172161, -0.049749838513716206,
-0.000915002981442826, -0.048502552862820653, -0.065383587718200784, 0.003175445066804758, -0.080194918286764838,
-0.077682133405468937, 0.033727063680071466, -0.150760186145271510, -0.084457338944868982, 0.505660603990009560,
 0.505660603990009560, -0.084457338944868982, -0.150760186145271510, 0.033727063680071466, -0.077682133405468937,
-0.080194918286764838, 0.003175445066804758, -0.065383587718200784, -0.048502552862820653, -0.000915002981442826,
-0.049749838513716206, -0.024817610540172161, 0.002675271476407882, -0.033405211299572850, -0.005919014059116164,
 0.007957114843116177, -0.018792331215007903, 0.007909156115753185, 0.011863897915831447, -0.007677125676925340,
 0.016195220864669575, 0.012945050783659821, -0.000836412988146811, 0.019134477971688185, 0.011004187010827985,
 0.001956966866997749, 0.017715945730523756, 0.006793369654665180, 0.001723883024608883, 0.013506207426436229,
 0.001601392930489681, -0.000120276288831242, 0.008239448308648542, -0.003207666910599826, -0.002192304121179012,
 0.003414827979152467, -0.006580016297377269, -0.003482125314769407, 0.000005086297602882, -0.008009304387660080,
-0.003534348839131837, -0.001651967564004321, -0.007574097052077259, -0.002440004582391299, -0.001784274911171613,
-0.005811280332409654, -0.000674076242033701, -0.000973631179709113, -0.003476112709865105, 0.001148919726851922,
 0.000106788350951055, -0.001290867165414506, 0.002501346935887695, 0.000915783375976514, 0.000249508373597955,
 0.003099108113624071, 0.001177319952191160, 0.000961093640197151, 0.002941734992852122, 0.000895615209137272,
 0.000942593074105167, 0.002255344271539108, 0.000284347316273074, 0.000470327395373754, 0.001366339327936554,
-0.000362220277410620, -0.000138017351197930, 0.000569610938158391, -0.000785665131620066, -0.000630232168612451,
 0.000024159967210229, -0.000852903625374087, -0.000870238259790123, -0.000283591051604510, -0.000586556150016652,
-0.000810984560171181, -0.000521640215250387, -0.000190964056763804, -0.000361216817648551, -0.000888985517068820,
-0.000374734941094989, 0.000925837447276999, 0.001125903700328483, 0.000382863369135811 } ;
// Sample 48000 Hz, pass 2350, stop 2650, ripple 1 dB, atten 80 dB.  Stop 0.05521.
double quiskMic5Filt48Coefs[424] = {
-0.000087601196745517, -0.000119178480453066, -0.000192494530734137, -0.000287398500897765, -0.000404455107555149,
-0.000542187350923721, -0.000697354821092750, -0.000864361814542882, -0.001035675409027330, -0.001201670675683178,
-0.001351260760102592, -0.001472389090721280, -0.001552963425946309, -0.001581622501567850, -0.001548788902291486,
-0.001447577149496593, -0.001274757191818737, -0.001031365182705646, -0.000723138798454071, -0.000360540808884225,
 0.000041472210381792, 0.000464151153253057, 0.000885978417045319, 0.001284080850383070, 0.001635786964228304,
 0.001920322587244723, 0.002120431736364362, 0.002223894227313585, 0.002224702189457267, 0.002123834204231122,
 0.001929455560771270, 0.001656578667677397, 0.001326124950893504, 0.000963492246325779, 0.000596656779876184,
 0.000254003709475283, -0.000037984405595945, -0.000256935860609037, -0.000386544706976665, -0.000418046328997344,
-0.000351100298847373, -0.000193939445451714, 0.000037212952694738, 0.000319460819342812, 0.000625164037239141,
 0.000924363583767082, 0.001187470307244314, 0.001388000318914036, 0.001505069987035192, 0.001525437805536890,
 0.001444870661224978, 0.001268714805496182, 0.001011568778937986, 0.000696080786323511, 0.000350937369521106,
 0.000008234786560396, -0.000299551487706380, -0.000542701008001189, -0.000697204883792079, -0.000747233312787443,
-0.000686876298204384, -0.000520952456912102, -0.000264798296929030, 0.000056986807722520, 0.000412734842368625,
 0.000766669398901066, 0.001082346669587512, 0.001326263088537886, 0.001471265194417923, 0.001499431895309172,
 0.001404113830652116, 0.001190910569750263, 0.000877443544384873, 0.000491924577078300, 0.000070618732748754,
-0.000345567500376679, -0.000715070316355716, -0.000999834598355945, -0.001169257920406941, -0.001203497801923855,
-0.001095797960360223, -0.000853559853825754, -0.000498020971159122, -0.000062520041312805, 0.000410511052497376,
 0.000873571510876301, 0.001278748950006680, 0.001582567444665569, 0.001750535054942567, 0.001760927137558775,
 0.001607388781175447, 0.001300061195708352, 0.000865065069005933, 0.000342348399080757, -0.000217942303300231,
-0.000760241586711499, -0.001229053244090960, -0.001574604672635160, -0.001758102209059370, -0.001756034066558804,
-0.001563058384174837, -0.001193131136885269, -0.000678706705799908, -0.000068024295664869, 0.000579300435978082,
 0.001197989750585395, 0.001723580332124720, 0.002099032072900320, 0.002280794678156941, 0.002243699390601673,
 0.001984133400353534, 0.001521121064322945, 0.000895127993320633, 0.000164637922390302, -0.000599227139535745,
-0.001319555291352399, -0.001921314886803284, -0.002339087231340391, -0.002524079501171732, -0.002449675079358536,
-0.002114908771525688, -0.001545437314172064, -0.000791823925944463, 0.000074782605168353, 0.000969218460672265,
 0.001800534718138737, 0.002481100933662590, 0.002935686794045762, 0.003109591237339856, 0.002974959532860613,
 0.002534577733743369, 0.001822671724082916, 0.000902520745944448, -0.000138980947793396, -0.001199369993895262,
-0.002170536435942518, -0.002949581024448342, -0.003449532389579513, -0.003608829916851618, -0.003398558758097474,
-0.002826619977722426, -0.001938296425724648, -0.000813026544735210, 0.000442428219163585, 0.001703859853903780,
 0.002841646272526556, 0.003733795631607910, 0.004278716742047143, 0.004406405339454943, 0.004086851240208961,
 0.003334703369161471, 0.002209574959936082, 0.000811784328342671, -0.000726216440571004, -0.002252031018207481,
-0.003608037091401704, -0.004647249273905110, -0.005248768326240763, -0.005331240183248048, -0.004862881229352157,
-0.003866915473379464, -0.002421678784759232, -0.000655151171295565, 0.001265777761167976, 0.003150462759634698,
 0.004802753890816374, 0.006040653489191535, 0.006715477432817280, 0.006728582425712883, 0.006043878643663059,
 0.004694681402232655, 0.002783951074178680, 0.000477576037627513, -0.002008976414542753, -0.004429653284750409,
-0.006530865070729735, -0.008076534379704757, -0.008872792811204462, -0.008789897699281934, -0.007779088447247421,
-0.005882478096374164, -0.003234645557614322, -0.000055318960121547, 0.003366648103157717, 0.006696974329608038,
 0.009585521827024799, 0.011699303862532495, 0.012756057470065627, 0.012555316826801740, 0.011004006112499458,
 0.008133925792679506, 0.004109116367295407, -0.000778103172178875, -0.006122670687011962, -0.011433128819157286,
-0.016167043119046529, -0.019772887723249422, -0.021735132723275978, -0.021618869254173001, -0.019110214094446909,
-0.014048964546840230, -0.006450511384232603, 0.003485174039118999, 0.015378649609086421, 0.028690243785521201,
 0.042752300360393465, 0.056812206812071039, 0.070083061994479681, 0.081798161497452851, 0.091265110934848792,
 0.097915351884672430, 0.101345208406692710, 0.101345208406692710, 0.097915351884672430, 0.091265110934848792,
 0.081798161497452851, 0.070083061994479681, 0.056812206812071039, 0.042752300360393465, 0.028690243785521201,
 0.015378649609086421, 0.003485174039118999, -0.006450511384232603, -0.014048964546840230, -0.019110214094446909,
-0.021618869254173001, -0.021735132723275978, -0.019772887723249422, -0.016167043119046529, -0.011433128819157286,
-0.006122670687011962, -0.000778103172178875, 0.004109116367295407, 0.008133925792679506, 0.011004006112499458,
 0.012555316826801740, 0.012756057470065627, 0.011699303862532495, 0.009585521827024799, 0.006696974329608038,
 0.003366648103157717, -0.000055318960121547, -0.003234645557614322, -0.005882478096374164, -0.007779088447247421,
-0.008789897699281934, -0.008872792811204462, -0.008076534379704757, -0.006530865070729735, -0.004429653284750409,
-0.002008976414542753, 0.000477576037627513, 0.002783951074178680, 0.004694681402232655, 0.006043878643663059,
 0.006728582425712883, 0.006715477432817280, 0.006040653489191535, 0.004802753890816374, 0.003150462759634698,
 0.001265777761167976, -0.000655151171295565, -0.002421678784759232, -0.003866915473379464, -0.004862881229352157,
-0.005331240183248048, -0.005248768326240763, -0.004647249273905110, -0.003608037091401704, -0.002252031018207481,
-0.000726216440571004, 0.000811784328342671, 0.002209574959936082, 0.003334703369161471, 0.004086851240208961,
 0.004406405339454943, 0.004278716742047143, 0.003733795631607910, 0.002841646272526556, 0.001703859853903780,
 0.000442428219163585, -0.000813026544735210, -0.001938296425724648, -0.002826619977722426, -0.003398558758097474,
-0.003608829916851618, -0.003449532389579513, -0.002949581024448342, -0.002170536435942518, -0.001199369993895262,
-0.000138980947793396, 0.000902520745944448, 0.001822671724082916, 0.002534577733743369, 0.002974959532860613,
 0.003109591237339856, 0.002935686794045762, 0.002481100933662590, 0.001800534718138737, 0.000969218460672265,
 0.000074782605168353, -0.000791823925944463, -0.001545437314172064, -0.002114908771525688, -0.002449675079358536,
-0.002524079501171732, -0.002339087231340391, -0.001921314886803284, -0.001319555291352399, -0.000599227139535745,
 0.000164637922390302, 0.000895127993320633, 0.001521121064322945, 0.001984133400353534, 0.002243699390601673,
 0.002280794678156941, 0.002099032072900320, 0.001723580332124720, 0.001197989750585395, 0.000579300435978082,
-0.000068024295664869, -0.000678706705799908, -0.001193131136885269, -0.001563058384174837, -0.001756034066558804,
-0.001758102209059370, -0.001574604672635160, -0.001229053244090960, -0.000760241586711499, -0.000217942303300231,
 0.000342348399080757, 0.000865065069005933, 0.001300061195708352, 0.001607388781175447, 0.001760927137558775,
 0.001750535054942567, 0.001582567444665569, 0.001278748950006680, 0.000873571510876301, 0.000410511052497376,
-0.000062520041312805, -0.000498020971159122, -0.000853559853825754, -0.001095797960360223, -0.001203497801923855,
-0.001169257920406941, -0.000999834598355945, -0.000715070316355716, -0.000345567500376679, 0.000070618732748754,
 0.000491924577078300, 0.000877443544384873, 0.001190910569750263, 0.001404113830652116, 0.001499431895309172,
 0.001471265194417923, 0.001326263088537886, 0.001082346669587512, 0.000766669398901066, 0.000412734842368625,
 0.000056986807722520, -0.000264798296929030, -0.000520952456912102, -0.000686876298204384, -0.000747233312787443,
-0.000697204883792079, -0.000542701008001189, -0.000299551487706380, 0.000008234786560396, 0.000350937369521106,
 0.000696080786323511, 0.001011568778937986, 0.001268714805496182, 0.001444870661224978, 0.001525437805536890,
 0.001505069987035192, 0.001388000318914036, 0.001187470307244314, 0.000924363583767082, 0.000625164037239141,
 0.000319460819342812, 0.000037212952694738, -0.000193939445451714, -0.000351100298847373, -0.000418046328997344,
-0.000386544706976665, -0.000256935860609037, -0.000037984405595945, 0.000254003709475283, 0.000596656779876184,
 0.000963492246325779, 0.001326124950893504, 0.001656578667677397, 0.001929455560771270, 0.002123834204231122,
 0.002224702189457267, 0.002223894227313585, 0.002120431736364362, 0.001920322587244723, 0.001635786964228304,
 0.001284080850383070, 0.000885978417045319, 0.000464151153253057, 0.000041472210381792, -0.000360540808884225,
-0.000723138798454071, -0.001031365182705646, -0.001274757191818737, -0.001447577149496593, -0.001548788902291486,
-0.001581622501567850, -0.001552963425946309, -0.001472389090721280, -0.001351260760102592, -0.001201670675683178,
-0.001035675409027330, -0.000864361814542882, -0.000697354821092750, -0.000542187350923721, -0.000404455107555149,
-0.000287398500897765, -0.000192494530734137, -0.000119178480453066, -0.000087601196745517} ;
